# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/income_report/v1/entry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/income_report/v1/entry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2
from meshtrade.type.v1 import amount_pb2 as meshtrade_dot_type_dot_v1_dot_amount__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0meshtrade/reporting/income_report/v1/entry.proto\x12$meshtrade.reporting.income_report.v1\x1a\x1dmeshtrade/type/v1/token.proto\x1a\x1emeshtrade/type/v1/amount.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfd\x02\n\x05\x45ntry\x12\x1d\n\nasset_name\x18\x01 \x01(\tR\tassetName\x12.\n\x05token\x18\x02 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x05token\x12.\n\x04\x64\x61te\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x64\x61te\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12M\n\tnarrative\x18\x05 \x01(\x0e\x32/.meshtrade.reporting.income_report.v1.NarrativeR\tnarrative\x12\x31\n\x06\x61mount\x18\x06 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x06\x61mount\x12Q\n\x17reported_currency_value\x18\x07 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x15reportedCurrencyValue*Q\n\tNarrative\x12\x19\n\x15NARRATIVE_UNSPECIFIED\x10\x00\x12\x13\n\x0fNARRATIVE_YIELD\x10\x01\x12\x14\n\x10NARRATIVE_COUPON\x10\x02\x42u\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.income_report.v1.entry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1'
  _globals['_NARRATIVE']._serialized_start=570
  _globals['_NARRATIVE']._serialized_end=651
  _globals['_ENTRY']._serialized_start=187
  _globals['_ENTRY']._serialized_end=568
# @@protoc_insertion_point(module_scope)
