# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/income_report/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/income_report/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.reporting.income_report.v1 import income_report_pb2 as meshtrade_dot_reporting_dot_income__report_dot_v1_dot_income__report__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2
from meshtrade.option.v1 import method_type_pb2 as meshtrade_dot_option_dot_v1_dot_method__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2meshtrade/reporting/income_report/v1/service.proto\x12$meshtrade.reporting.income_report.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x38meshtrade/reporting/income_report/v1/income_report.proto\x1a meshtrade/iam/role/v1/role.proto\x1a%meshtrade/option/v1/method_type.proto\"\x95\x01\n\x16GetIncomeReportRequest\x12\x1f\n\x0b\x61\x63\x63ount_num\x18\x01 \x01(\tR\naccountNum\x12.\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12*\n\x02to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02to\"\x82\x03\n\x1bGetExcelIncomeReportRequest\x12\x84\x01\n\x0b\x61\x63\x63ount_num\x18\x01 \x01(\tBc\xbaH`r\x0f\x10\x01\x32\x0b^[0-9]{1,}$\xba\x01L\n\x14\x61\x63\x63ount_num.required\x12\x17\x61\x63\x63ount_num is required\x1a\x1bthis.matches(\'^[0-9]{1,}$\')R\naccountNum\x12q\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBA\xbaH>\xba\x01;\n\rfrom.required\x12\x1c\'from\' timestamp is required\x1a\x0cthis != nullR\x04\x66rom\x12i\n\x02to\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB=\xbaH:\xba\x01\x37\n\x0bto.required\x12\x1a\'to\' timestamp is required\x1a\x0cthis != nullR\x02to\"A\n\x1cGetExcelIncomeReportResponse\x12!\n\x0c\x65xcel_base64\x18\x01 \x01(\tR\x0b\x65xcelBase642\xdb\x02\n\x13IncomeReportService\x12\x93\x01\n\x0fGetIncomeReport\x12<.meshtrade.reporting.income_report.v1.GetIncomeReportRequest\x1a\x32.meshtrade.reporting.income_report.v1.IncomeReport\"\x0e\xa0\xb5\x18\x01\xaa\xb5\x18\x06\n\x04\x81\x9b\xee\x02\x12\xad\x01\n\x14GetExcelIncomeReport\x12\x41.meshtrade.reporting.income_report.v1.GetExcelIncomeReportRequest\x1a\x42.meshtrade.reporting.income_report.v1.GetExcelIncomeReportResponse\"\x0e\xa0\xb5\x18\x01\xaa\xb5\x18\x06\n\x04\x81\x9b\xee\x02\x42u\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.income_report.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1'
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['account_num']._loaded_options = None
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['account_num']._serialized_options = b'\272H`r\017\020\0012\013^[0-9]{1,}$\272\001L\n\024account_num.required\022\027account_num is required\032\033this.matches(\'^[0-9]{1,}$\')'
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['from']._loaded_options = None
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['from']._serialized_options = b'\272H>\272\001;\n\rfrom.required\022\034\'from\' timestamp is required\032\014this != null'
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['to']._loaded_options = None
  _globals['_GETEXCELINCOMEREPORTREQUEST'].fields_by_name['to']._serialized_options = b'\272H:\272\0017\n\013to.required\022\032\'to\' timestamp is required\032\014this != null'
  _globals['_INCOMEREPORTSERVICE'].methods_by_name['GetIncomeReport']._loaded_options = None
  _globals['_INCOMEREPORTSERVICE'].methods_by_name['GetIncomeReport']._serialized_options = b'\240\265\030\001\252\265\030\006\n\004\201\233\356\002'
  _globals['_INCOMEREPORTSERVICE'].methods_by_name['GetExcelIncomeReport']._loaded_options = None
  _globals['_INCOMEREPORTSERVICE'].methods_by_name['GetExcelIncomeReport']._serialized_options = b'\240\265\030\001\252\265\030\006\n\004\201\233\356\002'
  _globals['_GETINCOMEREPORTREQUEST']._serialized_start=286
  _globals['_GETINCOMEREPORTREQUEST']._serialized_end=435
  _globals['_GETEXCELINCOMEREPORTREQUEST']._serialized_start=438
  _globals['_GETEXCELINCOMEREPORTREQUEST']._serialized_end=824
  _globals['_GETEXCELINCOMEREPORTRESPONSE']._serialized_start=826
  _globals['_GETEXCELINCOMEREPORTRESPONSE']._serialized_end=891
  _globals['_INCOMEREPORTSERVICE']._serialized_start=894
  _globals['_INCOMEREPORTSERVICE']._serialized_end=1241
# @@protoc_insertion_point(module_scope)
