# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/reporting/income_report/v1/income_report.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/reporting/income_report/v1/income_report.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2
from meshtrade.type.v1 import address_pb2 as meshtrade_dot_type_dot_v1_dot_address__pb2
from meshtrade.reporting.income_report.v1 import disclaimer_pb2 as meshtrade_dot_reporting_dot_income__report_dot_v1_dot_disclaimer__pb2
from meshtrade.reporting.income_report.v1 import entry_pb2 as meshtrade_dot_reporting_dot_income__report_dot_v1_dot_entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8meshtrade/reporting/income_report/v1/income_report.proto\x12$meshtrade.reporting.income_report.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dmeshtrade/type/v1/token.proto\x1a\x1fmeshtrade/type/v1/address.proto\x1a\x35meshtrade/reporting/income_report/v1/disclaimer.proto\x1a\x30meshtrade/reporting/income_report/v1/entry.proto\"\x99\x05\n\x0cIncomeReport\x12\x45\n\x07\x65ntries\x18\x01 \x03(\x0b\x32+.meshtrade.reporting.income_report.v1.EntryR\x07\x65ntries\x12G\n\x12reporting_currency\x18\x02 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x11reportingCurrency\x12Q\n\x06period\x18\x03 \x01(\x0b\x32\x39.meshtrade.reporting.income_report.v1.IncomeReport.PeriodR\x06period\x12\x43\n\x0fgeneration_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0egenerationDate\x12%\n\x0e\x61\x63\x63ount_number\x18\x05 \x01(\tR\raccountNumber\x12R\n\x0b\x64isclaimers\x18\x06 \x03(\x0b\x32\x30.meshtrade.reporting.income_report.v1.DisclaimerR\x0b\x64isclaimers\x12\x41\n\x0e\x63lient_address\x18\x07 \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\rclientAddress\x12\x1f\n\x0b\x63lient_name\x18\x08 \x01(\tR\nclientName\x12\x1c\n\tcopyright\x18\t \x01(\tR\tcopyright\x1a\x64\n\x06Period\x12.\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12*\n\x02to\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02toBu\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.reporting.income_report.v1.income_report_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+co.meshtrade.api.reporting.income_report.v1ZFgithub.com/meshtrade/api/go/reporting/income_report/v1;income_reportv1'
  _globals['_INCOMEREPORT']._serialized_start=301
  _globals['_INCOMEREPORT']._serialized_end=966
  _globals['_INCOMEREPORT_PERIOD']._serialized_start=866
  _globals['_INCOMEREPORT_PERIOD']._serialized_end=966
# @@protoc_insertion_point(module_scope)
